===============================
Remarker
===============================

.. image:: https://img.shields.io/travis/tylerdave/remarker.svg
        :target: https://travis-ci.org/tylerdave/remarker

.. image:: https://img.shields.io/pypi/v/remarker.svg
        :target: https://pypi.python.org/pypi/remarker


A command line tool for generating Remark.js presentations from markdown files.

* Free software: MIT license
* Documentation: (COMING SOON!) https://remarker.readthedocs.org.

Usage
-----

See ``remarker --help``

Usage Example
-------------

``remarker -o presentation.html slides.md``
